/*!
 * froala_editor v2.0.5 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms
 * Copyright 2014-2015 Froala Labs
 */

.clearfix::after {
  clear: both;
  display: block;
  content: "";
}
.dark-theme .fr-view table td,
.dark-theme .fr-view table th {
  border: 1px solid #dddddd;
}
.dark-theme .fr-view blockquote {
  border-left: solid 2px #5e35b1;
  color: #5e35b1;
}
.dark-theme .fr-view blockquote blockquote {
  border-color: #00bcd4;
  color: #00bcd4;
}
.dark-theme .fr-view blockquote blockquote blockquote {
  border-color: #43a047;
  color: #43a047;
}
.dark-theme img.fr-dib {
  margin-top: 5px;
  margin-bottom: 5px;
}
.dark-theme img.fr-dib.fr-fil {
  margin: 5px auto 5px 0;
  left: 5px;
}
.dark-theme img.fr-dib.fr-fir {
  margin: 5px 0 5px auto;
  right: 5px;
}
.dark-theme img.fr-dii {
  margin-top: 5px;
  margin-bottom: 5px;
}
.dark-theme img.fr-dii.fr-fil {
  margin: 5px 10px 5px 0;
  left: 5px;
}
.dark-theme img.fr-dii.fr-fir {
  margin: 5px 0 5px 10px;
  right: 5px;
}
.dark-theme .fr-tooltip {
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  -webkit-box-shadow: 0 3px 6px rgba(0, 0, 0, 0.16), 0 3px 6px rgba(0, 0, 0, 0.23);
  -moz-box-shadow: 0 3px 6px rgba(0, 0, 0, 0.16), 0 3px 6px rgba(0, 0, 0, 0.23);
  box-shadow: 0 3px 6px rgba(0, 0, 0, 0.16), 0 3px 6px rgba(0, 0, 0, 0.23);
  background: #222222;
  color: #ffffff;
  font-size: 11px;
  line-height: 22px;
  font-family: Arial, Helvetica, sans-serif;
  -webkit-transition: opacity 0.2s ease 0s;
  -moz-transition: opacity 0.2s ease 0s;
  -ms-transition: opacity 0.2s ease 0s;
  -o-transition: opacity 0.2s ease 0s;
}
.dark-theme .fr-element {
  color: #000000;
}
.dark-theme.fr-box.fr-basic .fr-element {
  padding: 10px;
}
.dark-theme .fr-wrapper .fr-placeholder {
  font-size: 12px;
  color: #aaaaaa;
}
.dark-theme .fr-wrapper ::selection {
  background: #b5d6fd;
  color: #000000;
}
.dark-theme .fr-wrapper ::-moz-selection {
  background: #b5d6fd;
  color: #000000;
}
.dark-theme.fr-box.fr-basic .fr-wrapper {
  background: #ffffff;
  border: 0px;
  border-top: 0;
}
.dark-theme.fr-box.fr-basic .fr-wrapper .fr-placeholder {
  top: 10px;
  left: 10px;
}
.dark-theme.fr-box.fr-basic.fr-top .fr-wrapper {
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  border-radius: 0 0 2px 2px;
  -moz-border-radius: 0 0 2px 2px;
  -webkit-border-radius: 0 0 2px 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}
.dark-theme.fr-box.fr-basic.fr-bottom .fr-wrapper {
  -webkit-box-shadow: 0 -1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  -moz-box-shadow: 0 -1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  box-shadow: 0 -1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  border-radius: 2px 2px 0 0;
  -moz-border-radius: 2px 2px 0 0;
  -webkit-border-radius: 2px 2px 0 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}
.dark-theme.fr-toolbar .fr-command.fr-btn,
.dark-theme.fr-popup .fr-command.fr-btn {
  color: #ffffff;
  margin: 0px 2px;
  -webkit-transition: background 0.2s ease 0s;
  -moz-transition: background 0.2s ease 0s;
  -ms-transition: background 0.2s ease 0s;
  -o-transition: background 0.2s ease 0s;
}
.dark-theme.fr-toolbar .fr-command.fr-btn i,
.dark-theme.fr-popup .fr-command.fr-btn i {
  font-size: 15px;
  width: 15px;
  margin: 11px 11.5px;
}
.dark-theme.fr-toolbar .fr-command.fr-btn span,
.dark-theme.fr-popup .fr-command.fr-btn span {
  font-size: 14px;
  line-height: 14px;
  margin: 11px 11.5px;
  min-width: 15px;
  height: 15px;
}
.dark-theme.fr-toolbar .fr-command.fr-btn img,
.dark-theme.fr-popup .fr-command.fr-btn img {
  margin: 11px 11.5px;
  width: 15px;
}
.dark-theme.fr-toolbar .fr-command.fr-btn.fr-active,
.dark-theme.fr-popup .fr-command.fr-btn.fr-active {
  color: #42a5f5;
  background: transparent;
}
.dark-theme.fr-toolbar .fr-command.fr-btn.fr-dropdown i,
.dark-theme.fr-popup .fr-command.fr-btn.fr-dropdown i,
.dark-theme.fr-toolbar .fr-command.fr-btn.fr-dropdown span,
.dark-theme.fr-popup .fr-command.fr-btn.fr-dropdown span,
.dark-theme.fr-toolbar .fr-command.fr-btn.fr-dropdown img,
.dark-theme.fr-popup .fr-command.fr-btn.fr-dropdown img {
  margin-left: 7.5px;
  margin-right: 15.5px;
}
.dark-theme.fr-toolbar .fr-command.fr-btn.fr-dropdown.fr-active,
.dark-theme.fr-popup .fr-command.fr-btn.fr-dropdown.fr-active {
  color: #ffffff;
  background: #2e2e2e;
}
.dark-theme.fr-toolbar .fr-command.fr-btn.fr-dropdown.fr-active:hover,
.dark-theme.fr-popup .fr-command.fr-btn.fr-dropdown.fr-active:hover,
.dark-theme.fr-toolbar .fr-command.fr-btn.fr-dropdown.fr-active:focus,
.dark-theme.fr-popup .fr-command.fr-btn.fr-dropdown.fr-active:focus {
  background: #2e2e2e !important;
  color: #ffffff !important;
}
.dark-theme.fr-toolbar .fr-command.fr-btn.fr-dropdown.fr-active:hover::after,
.dark-theme.fr-popup .fr-command.fr-btn.fr-dropdown.fr-active:hover::after,
.dark-theme.fr-toolbar .fr-command.fr-btn.fr-dropdown.fr-active:focus::after,
.dark-theme.fr-popup .fr-command.fr-btn.fr-dropdown.fr-active:focus::after {
  border-top-color: #ffffff !important;
}
.dark-theme.fr-toolbar .fr-command.fr-btn.fr-dropdown::after,
.dark-theme.fr-popup .fr-command.fr-btn.fr-dropdown::after {
  border-left: 4px solid transparent;
  border-right: 4px solid transparent;
  border-top: 4px solid #ffffff;
  right: 3.75px;
  top: 16.5px;
}
.dark-theme.fr-toolbar .fr-command.fr-btn.fr-disabled,
.dark-theme.fr-popup .fr-command.fr-btn.fr-disabled {
  color: #808080;
}
.dark-theme.fr-toolbar .fr-command.fr-btn.fr-disabled::after,
.dark-theme.fr-popup .fr-command.fr-btn.fr-disabled::after {
  border-top-color: #808080;
}
.dark-theme.fr-toolbar.fr-disabled .fr-btn,
.dark-theme.fr-popup.fr-disabled .fr-btn,
.dark-theme.fr-toolbar.fr-disabled .fr-btn.fr-active,
.dark-theme.fr-popup.fr-disabled .fr-btn.fr-active {
  color: #808080;
}
.dark-theme.fr-toolbar.fr-disabled .fr-btn.fr-dropdown::after,
.dark-theme.fr-popup.fr-disabled .fr-btn.fr-dropdown::after,
.dark-theme.fr-toolbar.fr-disabled .fr-btn.fr-active.fr-dropdown::after,
.dark-theme.fr-popup.fr-disabled .fr-btn.fr-active.fr-dropdown::after {
  border-top-color: #808080;
}
.dark-theme.fr-desktop .fr-command:hover,
.dark-theme.fr-desktop .fr-command:focus {
  color: #ffffff;
  background: #3d3d3d;
}
.dark-theme.fr-desktop .fr-command:hover::after,
.dark-theme.fr-desktop .fr-command:focus::after {
  border-top-color: #ffffff !important;
}
.dark-theme.fr-desktop .fr-command.fr-selected {
  color: #ffffff;
  background: #2e2e2e;
}
.dark-theme.fr-desktop .fr-command.fr-active:hover,
.dark-theme.fr-desktop .fr-command.fr-active:focus {
  color: #42a5f5;
  background: #3d3d3d;
}
.dark-theme.fr-desktop .fr-command.fr-active.fr-selected {
  color: #42a5f5;
  background: #2e2e2e;
}
.dark-theme.fr-desktop .fr-command.fr-disabled:hover,
.dark-theme.fr-desktop .fr-command.fr-disabled:focus,
.dark-theme.fr-desktop .fr-command.fr-disabled.fr-selected {
  background: transparent;
}
.dark-theme.fr-toolbar.fr-mobile .fr-command.fr-blink,
.dark-theme.fr-popup.fr-mobile .fr-command.fr-blink {
  background: transparent;
}
.dark-theme .fr-command.fr-btn + .fr-dropdown-menu {
  -webkit-box-shadow: 0 3px 6px rgba(0, 0, 0, 0.16), 0 3px 6px rgba(0, 0, 0, 0.23);
  -moz-box-shadow: 0 3px 6px rgba(0, 0, 0, 0.16), 0 3px 6px rgba(0, 0, 0, 0.23);
  box-shadow: 0 3px 6px rgba(0, 0, 0, 0.16), 0 3px 6px rgba(0, 0, 0, 0.23);
  border-radius: 0 0 2px 2px;
  -moz-border-radius: 0 0 2px 2px;
  -webkit-border-radius: 0 0 2px 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}
.dark-theme .fr-command.fr-btn + .fr-dropdown-menu .fr-dropdown-wrapper {
  background: #353535;
  -webkit-box-shadow: 0 3px 6px rgba(0, 0, 0, 0.16), 0 3px 6px rgba(0, 0, 0, 0.23);
  -moz-box-shadow: 0 3px 6px rgba(0, 0, 0, 0.16), 0 3px 6px rgba(0, 0, 0, 0.23);
  box-shadow: 0 3px 6px rgba(0, 0, 0, 0.16), 0 3px 6px rgba(0, 0, 0, 0.23);
  -webkit-transition: max-height 0.2s ease 0s;
  -moz-transition: max-height 0.2s ease 0s;
  -ms-transition: max-height 0.2s ease 0s;
  -o-transition: max-height 0.2s ease 0s;
}
.dark-theme .fr-command.fr-btn + .fr-dropdown-menu .fr-dropdown-wrapper .fr-dropdown-content {
  max-height: 275px;
}
.dark-theme .fr-command.fr-btn + .fr-dropdown-menu .fr-dropdown-wrapper .fr-dropdown-content ul.fr-dropdown-list li a.fr-active {
  background: #2e2e2e;
}
.dark-theme .fr-command.fr-btn + .fr-dropdown-menu .fr-dropdown-wrapper .fr-dropdown-content ul.fr-dropdown-list li a.fr-disabled {
  color: #808080;
}
.dark-theme .fr-command.fr-btn.fr-active + .fr-dropdown-menu .fr-dropdown-wrapper {
  max-height: 275px;
}
.dark-theme .fr-bottom > .fr-command.fr-btn + .fr-dropdown-menu {
  border-radius: 2px 2px 0 0;
  -moz-border-radius: 2px 2px 0 0;
  -webkit-border-radius: 2px 2px 0 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}
.dark-theme.fr-popup {
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  color: #ffffff;
  background: #353535;
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  font-family: Arial, Helvetica, sans-serif;
  border: 0px;
  border-top: 5px solid #222222;
}
.dark-theme.fr-popup.fr-above {
  border-bottom: 5px solid #222222;
  -webkit-box-shadow: 0 -1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  -moz-box-shadow: 0 -1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  box-shadow: 0 -1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
}
.dark-theme.fr-popup .fr-input-line input[type="text"],
.dark-theme.fr-popup .fr-input-line textarea {
  color: #ffffff;
  border-bottom: solid 1px #bdbdbd;
}
.dark-theme.fr-popup .fr-input-line input[type="text"]:focus,
.dark-theme.fr-popup .fr-input-line textarea:focus {
  border-bottom: solid 2px #42a5f5;
}
.dark-theme.fr-popup .fr-input-line input + span,
.dark-theme.fr-popup .fr-input-line textarea + span {
  -webkit-transition: color 0.2s ease 0s;
  -moz-transition: color 0.2s ease 0s;
  -ms-transition: color 0.2s ease 0s;
  -o-transition: color 0.2s ease 0s;
}
.dark-theme.fr-popup .fr-input-line input.fr-not-empty:focus + span,
.dark-theme.fr-popup .fr-input-line textarea.fr-not-empty:focus + span {
  color: #42a5f5;
}
.dark-theme.fr-popup .fr-input-line input.fr-not-empty + span,
.dark-theme.fr-popup .fr-input-line textarea.fr-not-empty + span {
  color: #808080;
}
.dark-theme.fr-popup .fr-buttons {
  padding: 0 2px;
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  border-bottom: 0px;
}
.dark-theme.fr-popup .fr-layer {
  width: 225px;
}
@media (min-width: 768px) {
  .dark-theme.fr-popup .fr-layer {
    width: 300px;
  }
}
.dark-theme.fr-popup .fr-action-buttons button.fr-command {
  color: #42a5f5;
  -webkit-transition: background 0.2s ease 0s;
  -moz-transition: background 0.2s ease 0s;
  -ms-transition: background 0.2s ease 0s;
  -o-transition: background 0.2s ease 0s;
}
.dark-theme.fr-popup .fr-action-buttons button.fr-command:hover,
.dark-theme.fr-popup .fr-action-buttons button.fr-command:focus {
  background: #3d3d3d;
  color: #42a5f5;
}
.dark-theme.fr-popup .fr-action-buttons button.fr-command:active {
  background: #2e2e2e;
  color: #42a5f5;
}
.dark-theme.fr-popup .fr-checkbox span {
  border: solid 1px #ffffff;
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  -webkit-transition: background 0.2s ease 0s, border-color 0.2s ease 0s;
  -moz-transition: background 0.2s ease 0s, border-color 0.2s ease 0s;
  -ms-transition: background 0.2s ease 0s, border-color 0.2s ease 0s;
  -o-transition: background 0.2s ease 0s, border-color 0.2s ease 0s;
}
.dark-theme.fr-popup .fr-checkbox input:checked + span {
  background: #42a5f5;
  border-color: #42a5f5;
}
.dark-theme.fr-popup .fr-checkbox input:focus + span {
  border-color: #42a5f5;
}
.dark-theme.fr-popup.fr-desktop .fr-arrow {
  border-left: 5px solid transparent;
  border-right: 5px solid transparent;
  border-bottom: 5px solid #222222;
  top: -9px;
  margin-left: -5px;
}
.dark-theme.fr-popup.fr-desktop.fr-above .fr-arrow {
  bottom: -9px;
  border-top-width: 5px;
}
.dark-theme.fr-toolbar {
  color: #ffffff;
  background: #353535;
  font-family: Arial, Helvetica, sans-serif;
  padding: 0 2px;
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  border: 0px;
  border-top: 5px solid #222222;
}
.dark-theme.fr-toolbar.fr-inline.fr-desktop .fr-arrow {
  border-left: 5px solid transparent;
  border-right: 5px solid transparent;
  border-bottom: 5px solid #222222;
  top: -9px;
  margin-left: -5px;
}
.dark-theme.fr-toolbar.fr-inline.fr-desktop.fr-above {
  border-bottom: 5px solid #222222;
  -webkit-box-shadow: 0 -1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  -moz-box-shadow: 0 -1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  box-shadow: 0 -1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
}
.dark-theme.fr-toolbar.fr-inline.fr-desktop.fr-above .fr-arrow {
  bottom: -9px;
  border-top-width: 5px;
}
.dark-theme.fr-toolbar.fr-top {
  border-radius: 2px 2px 0 0;
  -moz-border-radius: 2px 2px 0 0;
  -webkit-border-radius: 2px 2px 0 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
}
.dark-theme.fr-toolbar.fr-bottom {
  border-radius: 0 0 2px 2px;
  -moz-border-radius: 0 0 2px 2px;
  -webkit-border-radius: 0 0 2px 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
}
.dark-theme .fr-separator {
  background: #595959;
}
.dark-theme .fr-separator.fr-vs {
  height: 33px;
  width: 1px;
  margin: 2px;
}
.dark-theme .fr-separator.fr-hs {
  height: 1px;
  width: calc(100% - (2 * 2px));
  margin: 0 2px;
}
.dark-theme.fr-box .fr-counter {
  color: #aaaaaa;
  background: #ffffff;
  border-top: solid 1px #595959;
  border-left: solid 1px #595959;
  border-radius: 2px 0 0 0;
  -moz-border-radius: 2px 0 0 0;
  -webkit-border-radius: 2px 0 0 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}
.dark-theme.fr-box.fr-rtl .fr-counter {
  border-right: solid 1px #595959;
  border-radius: 0 2px 0 0;
  -moz-border-radius: 0 2px 0 0;
  -webkit-border-radius: 0 2px 0 0;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
}
.dark-theme textarea.fr-code {
  background: #ffffff;
  color: #000000;
}
.dark-theme .fr-box.fr-code-view.fr-inline {
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
}
.dark-theme.fr-box.fr-inline .fr-command.fr-btn.html-switch {
  background: #ffffff;
  color: #ffffff;
  padding: 11px 11.5px;
  -webkit-transition: background 0.2s ease 0s;
  -moz-transition: background 0.2s ease 0s;
  -ms-transition: background 0.2s ease 0s;
  -o-transition: background 0.2s ease 0s;
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
}
.dark-theme.fr-box.fr-inline .fr-command.fr-btn.html-switch i {
  font-size: 15px;
  width: 15px;
}
.dark-theme.fr-box.fr-inline .fr-command.fr-btn.html-switch.fr-desktop:hover {
  background: #3d3d3d;
}
.dark-theme.fr-popup .fr-colors-tabs {
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
}
.dark-theme.fr-popup .fr-colors-tabs .fr-colors-tab {
  color: #ffffff;
}
.dark-theme.fr-popup .fr-colors-tabs .fr-colors-tab:hover {
  color: #42a5f5;
}
.dark-theme.fr-popup .fr-colors-tabs .fr-colors-tab[data-param1="background"]::after {
  background: #42a5f5;
  -webkit-transition: transform 0.2s ease 0s;
  -moz-transition: transform 0.2s ease 0s;
  -ms-transition: transform 0.2s ease 0s;
  -o-transition: transform 0.2s ease 0s;
}
.dark-theme.fr-popup .fr-colors-tabs .fr-colors-tab.fr-selected-tab {
  color: #42a5f5;
}
.dark-theme.fr-popup .fr-color-set > span.fr-selected-color::after {
  color: #ffffff;
}
.dark-theme.fr-popup .fr-color-set > span:hover,
.dark-theme.fr-popup .fr-color-set > span.fr-selected-color {
  outline: 1px solid #ffffff;
}
.dark-theme .fr-file-upload-layer {
  border: dashed 2px #808080;
}
.dark-theme .fr-file-upload-layer:hover {
  background: #3d3d3d;
}
.dark-theme .fr-file-upload-layer.fr-drop {
  background: #3d3d3d;
  border-color: #42a5f5;
}
.dark-theme .fr-file-progress-bar-layer > div.fr-loader {
  background: #c6e4fc;
}
.dark-theme .fr-file-progress-bar-layer > div.fr-loader span {
  background: #42a5f5;
  -webkit-transition: width 0.2s ease 0s;
  -moz-transition: width 0.2s ease 0s;
  -ms-transition: width 0.2s ease 0s;
  -o-transition: width 0.2s ease 0s;
}
.dark-theme .fr-image-resizer {
  border: solid 1px #42a5f5;
}
.dark-theme .fr-image-resizer .fr-handler {
  background: #42a5f5;
  border: solid 1px #ffffff;
}
.dark-theme .fr-image-resizer .fr-handler {
  width: 12px;
  height: 12px;
}
.dark-theme .fr-image-resizer .fr-handler.fr-hnw {
  left: -6px;
  top: -6px;
}
.dark-theme .fr-image-resizer .fr-handler.fr-hne {
  right: -6px;
  top: -6px;
}
.dark-theme .fr-image-resizer .fr-handler.fr-hsw {
  left: -6px;
  bottom: -6px;
}
.dark-theme .fr-image-resizer .fr-handler.fr-hse {
  right: -6px;
  bottom: -6px;
}
@media (min-width: 1200px) {
  .dark-theme .fr-image-resizer .fr-handler {
    width: 10px;
    height: 10px;
  }
  .dark-theme .fr-image-resizer .fr-handler.fr-hnw {
    left: -5px;
    top: -5px;
  }
  .dark-theme .fr-image-resizer .fr-handler.fr-hne {
    right: -5px;
    top: -5px;
  }
  .dark-theme .fr-image-resizer .fr-handler.fr-hsw {
    left: -5px;
    bottom: -5px;
  }
  .dark-theme .fr-image-resizer .fr-handler.fr-hse {
    right: -5px;
    bottom: -5px;
  }
}
.dark-theme .fr-image-upload-layer {
  border: dashed 2px #808080;
}
.dark-theme .fr-image-upload-layer:hover {
  background: #3d3d3d;
}
.dark-theme .fr-image-upload-layer.fr-drop {
  background: #3d3d3d;
  border-color: #42a5f5;
}
.dark-theme .fr-image-progress-bar-layer > div.fr-loader {
  background: #c6e4fc;
}
.dark-theme .fr-image-progress-bar-layer > div.fr-loader span {
  background: #42a5f5;
  -webkit-transition: width 0.2s ease 0s;
  -moz-transition: width 0.2s ease 0s;
  -ms-transition: width 0.2s ease 0s;
  -o-transition: width 0.2s ease 0s;
}
.dark-theme .fr-line-breaker {
  border-top: 1px solid #42a5f5;
}
.dark-theme .fr-line-breaker a {
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  height: 24px;
  width: 24px;
  top: -12px;
  background: #42a5f5;
  color: #000000;
  -webkit-transition: background 0.2s ease 0s, color 0.2s ease 0s;
  -moz-transition: background 0.2s ease 0s, color 0.2s ease 0s;
  -ms-transition: background 0.2s ease 0s, color 0.2s ease 0s;
  -o-transition: background 0.2s ease 0s, color 0.2s ease 0s;
}
.dark-theme .fr-line-breaker a:hover {
  background: #222222;
  color: #ffffff;
}
.dark-theme .fr-line-breaker a i {
  line-height: 24px;
}
.dark-theme table td.fr-selected-cell,
.dark-theme table th.fr-selected-cell {
  border: 1px double #42a5f5;
}
.dark-theme .fr-table-resizer div {
  border-right: 1px solid #42a5f5;
}
.dark-theme.fr-popup .fr-table-size .fr-select-table-size > span > span {
  border: 1px solid #dddddd;
}
.dark-theme.fr-popup .fr-table-size .fr-select-table-size > span:hover > span,
.dark-theme.fr-popup .fr-table-size .fr-select-table-size > span.hover > span {
  background: rgba(66, 165, 245, 0.3);
  border: solid 1px #42a5f5;
}
.dark-theme.fr-popup .fr-table-colors > span.fr-selected-color::after {
  color: #ffffff;
}
.dark-theme.fr-popup .fr-table-colors > span:hover,
.dark-theme.fr-popup .fr-table-colors > span.fr-selected-color {
  outline: 1px solid #ffffff;
}
.dark-theme .fr-box .fr-video-resizer {
  border: solid 1px #42a5f5;
}
.dark-theme .fr-box .fr-video-resizer .fr-handler {
  background: #42a5f5;
  border: solid 1px #ffffff;
}
.dark-theme .fr-box .fr-video-resizer .fr-handler {
  width: 12px;
  height: 12px;
}
.dark-theme .fr-box .fr-video-resizer .fr-handler.fr-hnw {
  left: -6px;
  top: -6px;
}
.dark-theme .fr-box .fr-video-resizer .fr-handler.fr-hne {
  right: -6px;
  top: -6px;
}
.dark-theme .fr-box .fr-video-resizer .fr-handler.fr-hsw {
  left: -6px;
  bottom: -6px;
}
.dark-theme .fr-box .fr-video-resizer .fr-handler.fr-hse {
  right: -6px;
  bottom: -6px;
}
@media (min-width: 1200px) {
  .dark-theme .fr-box .fr-video-resizer .fr-handler {
    width: 10px;
    height: 10px;
  }
  .dark-theme .fr-box .fr-video-resizer .fr-handler.fr-hnw {
    left: -5px;
    top: -5px;
  }
  .dark-theme .fr-box .fr-video-resizer .fr-handler.fr-hne {
    right: -5px;
    top: -5px;
  }
  .dark-theme .fr-box .fr-video-resizer .fr-handler.fr-hsw {
    left: -5px;
    bottom: -5px;
  }
  .dark-theme .fr-box .fr-video-resizer .fr-handler.fr-hse {
    right: -5px;
    bottom: -5px;
  }
}
.dark-theme.fr-modal .fr-modal-wrapper {
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  background: #ffffff;
  -webkit-box-shadow: 0 10px 20px rgba(0, 0, 0, 0.19), 0 6px 6px rgba(0, 0, 0, 0.23);
  -moz-box-shadow: 0 10px 20px rgba(0, 0, 0, 0.19), 0 6px 6px rgba(0, 0, 0, 0.23);
  box-shadow: 0 10px 20px rgba(0, 0, 0, 0.19), 0 6px 6px rgba(0, 0, 0, 0.23);
  border: 0px;
  border-top: 5px solid #222222;
}
.dark-theme.fr-modal .fr-modal-wrapper .fr-modal-title {
  background: #353535;
  -webkit-transition: height 0.2s ease 0s;
  -moz-transition: height 0.2s ease 0s;
  -ms-transition: height 0.2s ease 0s;
  -o-transition: height 0.2s ease 0s;
  -webkit-box-shadow: 0 3px 6px rgba(0, 0, 0, 0.16), 0 3px 6px rgba(0, 0, 0, 0.23);
  -moz-box-shadow: 0 3px 6px rgba(0, 0, 0, 0.16), 0 3px 6px rgba(0, 0, 0, 0.23);
  box-shadow: 0 3px 6px rgba(0, 0, 0, 0.16), 0 3px 6px rgba(0, 0, 0, 0.23);
  border-bottom: 0px;
}
.dark-theme.fr-modal .fr-modal-wrapper .fr-modal-title .fr-modal-title-line h4 {
  color: #ffffff;
}
.dark-theme.fr-modal .fr-modal-wrapper .fr-modal-title .fr-modal-title-line i {
  color: #ffffff;
}
.dark-theme.fr-modal .fr-modal-wrapper .fr-modal-title .fr-modal-title-line i.fr-modal-more {
  -webkit-transition: padding 0.2s ease 0s, width 0.2s ease 0s, opacity 0.2s ease 0s;
  -moz-transition: padding 0.2s ease 0s, width 0.2s ease 0s, opacity 0.2s ease 0s;
  -ms-transition: padding 0.2s ease 0s, width 0.2s ease 0s, opacity 0.2s ease 0s;
  -o-transition: padding 0.2s ease 0s, width 0.2s ease 0s, opacity 0.2s ease 0s;
}
.dark-theme.fr-modal .fr-modal-wrapper .fr-modal-title .fr-modal-title-line i.fr-modal-close {
  -webkit-transition: color 0.2s ease 0s;
  -moz-transition: color 0.2s ease 0s;
  -ms-transition: color 0.2s ease 0s;
  -o-transition: color 0.2s ease 0s;
}
.dark-theme.fr-modal .fr-modal-wrapper .fr-modal-title .fr-modal-tags a {
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  color: #42a5f5;
  -webkit-transition: opacity 0.2s ease 0s, background 0.2s ease 0s;
  -moz-transition: opacity 0.2s ease 0s, background 0.2s ease 0s;
  -ms-transition: opacity 0.2s ease 0s, background 0.2s ease 0s;
  -o-transition: opacity 0.2s ease 0s, background 0.2s ease 0s;
}
.dark-theme.fr-modal .fr-modal-wrapper .fr-modal-title .fr-modal-tags a.fr-selected-tag {
  background: #2e2e2e;
}
.dark-theme.fr-modal .fr-modal-wrapper div.fr-scroller div.fr-image-list div.fr-image-container {
  border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  background-clip: padding-box;
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
}
.dark-theme.fr-modal .fr-modal-wrapper div.fr-scroller div.fr-image-list div.fr-image-container.fr-image-deleting::after {
  -webkit-transition: opacity 0.2s ease 0s;
  -moz-transition: opacity 0.2s ease 0s;
  -ms-transition: opacity 0.2s ease 0s;
  -o-transition: opacity 0.2s ease 0s;
  background: #000000;
}
.dark-theme.fr-modal .fr-modal-wrapper div.fr-scroller div.fr-image-list div.fr-image-container.fr-image-deleting::before {
  color: #ffffff;
}
.dark-theme.fr-modal .fr-modal-wrapper div.fr-scroller div.fr-image-list div.fr-image-container.fr-empty {
  background: #aaaaaa;
}
.dark-theme.fr-modal .fr-modal-wrapper div.fr-scroller div.fr-image-list div.fr-image-container img {
  -webkit-transition: opacity 0.2s ease 0s, filter 0.2s ease 0s;
  -moz-transition: opacity 0.2s ease 0s, filter 0.2s ease 0s;
  -ms-transition: opacity 0.2s ease 0s, filter 0.2s ease 0s;
  -o-transition: opacity 0.2s ease 0s, filter 0.2s ease 0s;
}
.dark-theme.fr-modal .fr-modal-wrapper div.fr-scroller div.fr-image-list div.fr-image-container .fr-delete-img,
.dark-theme.fr-modal .fr-modal-wrapper div.fr-scroller div.fr-image-list div.fr-image-container .fr-insert-img {
  -webkit-transition: background 0.2s ease 0s, color 0.2s ease 0s;
  -moz-transition: background 0.2s ease 0s, color 0.2s ease 0s;
  -ms-transition: background 0.2s ease 0s, color 0.2s ease 0s;
  -o-transition: background 0.2s ease 0s, color 0.2s ease 0s;
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
}
.dark-theme.fr-modal .fr-modal-wrapper div.fr-scroller div.fr-image-list div.fr-image-container .fr-delete-img {
  background: #b8312f;
  color: #ffffff;
}
.dark-theme.fr-modal .fr-modal-wrapper div.fr-scroller div.fr-image-list div.fr-image-container .fr-insert-img {
  background: #353535;
  color: #42a5f5;
}
.dark-theme.fr-modal.fr-desktop .fr-modal-wrapper .fr-modal-title .fr-modal-title-line i:hover {
  background: #3d3d3d;
}
.dark-theme.fr-modal.fr-desktop .fr-modal-wrapper .fr-modal-title .fr-modal-tags a:hover {
  background: #3d3d3d;
}
.dark-theme.fr-modal.fr-desktop .fr-modal-wrapper .fr-modal-title .fr-modal-tags a.fr-selected-tag {
  background: #2e2e2e;
}
.dark-theme.fr-modal.fr-desktop .fr-modal-wrapper div.fr-scroller div.fr-image-list div.fr-image-container .fr-delete-img:hover {
  background: #bf4644;
  color: #ffffff;
}
.dark-theme.fr-modal.fr-desktop .fr-modal-wrapper div.fr-scroller div.fr-image-list div.fr-image-container .fr-insert-img:hover {
  background: #3d3d3d;
}
.dark-theme.fr-overlay {
  background: #000000;
}
